@@ -21,6 +21,7 @@ from zaqar.common.api.schemas import flavors as schema
 from zaqar.common import utils as common_utils
 from zaqar.i18n import _
 from zaqar.storage import errors
+from zaqar.transport import acl
 from zaqar.transport import utils as transport_utils
 from zaqar.transport.wsgi import errors as wsgi_errors
 from zaqar.transport.wsgi import utils as wsgi_utils
@@ -34,9 +35,11 @@ class Listing(object):
     :param flavors_controller: means to interact with storage
     """
 
-    def __init__(self, flavors_controller):
+    def __init__(self, flavors_controller, pools_controller):
         self._ctrl = flavors_controller
+        self._pools_ctrl = pools_controller
 
+    @acl.enforce("flavors:get_all")
     def on_get(self, request, response, project_id):
         """Returns a flavor listing as objects embedded in an object:
 
@@ -61,7 +64,7 @@ class Listing(object):
         store = {}
         request.get_param('marker', store=store)
         request.get_param_as_int('limit', store=store)
-        request.get_param_as_bool('detailed', store=store)
+        detailed = request.get_param_as_bool('detailed')
 
         cursor = self._ctrl.list(project=project_id, **store)
         flavors = list(next(cursor))
@@ -73,7 +76,15 @@ class Listing(object):
 
             for entry in flavors:
                 entry['href'] = request.path + '/' + entry['name']
+                if detailed:
+                    caps = self._pools_ctrl.capabilities(group=entry['pool'])
+                    entry['capabilities'] = [str(cap).split('.')[-1]
+                                             for cap in caps]
 
+        if detailed is not None:
+            store['detailed'] = detailed
+
+        if flavors:
             results['links'] = [
                 {
                     'rel': 'next',
@@ -93,8 +104,10 @@ class Resource(object):
     :param flavors_controller: means to interact with storage
     """
 
-    def __init__(self, flavors_controller):
+    def __init__(self, flavors_controller, pools_controller):
         self._ctrl = flavors_controller
+        self._pools_ctrl = pools_controller
+
         validator_type = jsonschema.Draft4Validator
         self._validators = {
             'create': validator_type(schema.create),
@@ -102,6 +115,7 @@ class Resource(object):
             'capabilities': validator_type(schema.patch_capabilities),
         }
 
+    @acl.enforce("flavors:get")
     def on_get(self, request, response, project_id, flavor):
         """Returns a JSON object for a single flavor entry:
 
@@ -114,12 +128,12 @@ class Resource(object):
 
         LOG.debug(u'GET flavor - name: %s', flavor)
         data = None
-        detailed = request.get_param_as_bool('detailed') or False
 
         try:
-            data = self._ctrl.get(flavor,
-                                  project=project_id,
-                                  detailed=detailed)
+            data = self._ctrl.get(flavor, project=project_id)
+            capabilities = self._pools_ctrl.capabilities(group=data['pool'])
+            data['capabilities'] = [str(cap).split('.')[-1]
+                                    for cap in capabilities]
 
         except errors.FlavorDoesNotExist as ex:
             LOG.debug(ex)
@@ -129,6 +143,7 @@ class Resource(object):
 
         response.body = transport_utils.to_json(data)
 
+    @acl.enforce("flavors:create")
     def on_put(self, request, response, project_id, flavor):
         """Registers a new flavor. Expects the following input:
 
@@ -149,8 +164,7 @@ class Resource(object):
         try:
             self._ctrl.create(flavor,
                               pool=data['pool'],
-                              project=project_id,
-                              capabilities=data['capabilities'])
+                              project=project_id)
             response.status = falcon.HTTP_201
             response.location = request.path
         except errors.PoolDoesNotExist as ex:
@@ -160,6 +174,7 @@ class Resource(object):
                            dict(flavor=flavor, pool=data['pool']))
             raise falcon.HTTPBadRequest(_('Unable to create'), description)
 
+    @acl.enforce("flavors:delete")
     def on_delete(self, request, response, project_id, flavor):
         """Deregisters a flavor.
 
@@ -170,6 +185,7 @@ class Resource(object):
         self._ctrl.delete(flavor, project=project_id)
         response.status = falcon.HTTP_204
 
+    @acl.enforce("flavors:update")
     def on_patch(self, request, response, project_id, flavor):
         """Allows one to update a flavors's pool and/or capabilities.
 
@@ -186,12 +202,11 @@ class Resource(object):
         LOG.debug(u'PATCH flavor - name: %s', flavor)
         data = wsgi_utils.load(request)
 
-        EXPECT = ('pool', 'capabilities')
+        EXPECT = ('pool', )
         if not any([(field in data) for field in EXPECT]):
             LOG.debug(u'PATCH flavor, bad params')
             raise wsgi_errors.HTTPBadRequestBody(
-                'One of `pool` or `capabilities` needs '
-                'to be specified'
+                'One of `pool` needs to be specified'
             )
 
         for field in EXPECT:
